==> rustc_1.83.0+dfsg1.orig.tar.xz: rustc-1.83.0-src/tests/rustdoc-js-std/parser-quote.js <==
const PARSED = [
    {
        query: '-> "p"',
        elems: [],
        foundElems: 1,
        original: '-> "p"',
        returned: [{
            name: "p",
            fullPath: ["p"],
            pathWithoutLast: [],
            pathLast: "p",
            generics: [],
            typeFilter: -1,
        }],
        userQuery: '-> "p"',
        error: null,
    },
    {
        query: '"p",',
        elems: [{
            name: "p",
            fullPath: ["p"],
            pathWithoutLast: [],
            pathLast: "p",
            generics: [],
            typeFilter: -1,
        }],
        foundElems: 1,
        original: '"p",',
        returned: [],
        userQuery: '"p",',
        error: null,
    },
    {
        query: '"p" -> a',
        elems: [],
        foundElems: 0,
        original: '"p" -> a',
        returned: [],
        userQuery: '"p" -> a',
        error: "Cannot have more than one element if you use quotes",
    },
    {
        query: '"a" -> "p"',
        elems: [],
        foundElems: 0,
        original: '"a" -> "p"',
        returned: [],
        userQuery: '"a" -> "p"',
        error: "Cannot have more than one literal search element",
    },
    {
        query: '->"-"',
        elems: [],
        foundElems: 0,
        original: '->"-"',
        returned: [],
        userQuery: '->"-"',
        error: 'Unexpected `-` in a string element',
    },
    {
        query: '"a',
        elems: [],
        foundElems: 0,
        original: '"a',
        returned: [],
        userQuery: '"a',
        error: 'Unclosed `"`',
    },
    {
        query: '""',
        elems: [],
        foundElems: 0,
        original: '""',
        returned: [],
        userQuery: '""',
        error: 'Cannot have empty string element',
    },
];

==> rustc_1.91.1+dfsg1.orig.tar.xz: rustc-1.91.1-src/tests/rustdoc-js-std/parser-quote.js <==
const PARSED = [
    {
        query: '-> "p"',
        elems: [],
        foundElems: 1,
        userQuery: '-> "p"',
        returned: [{
            name: "p",
            fullPath: ["p"],
            pathWithoutLast: [],
            pathLast: "p",
            generics: [],
            typeFilter: null,
        }],
        error: null,
    },
    {
        query: '"p",',
        elems: [{
            name: "p",
            fullPath: ["p"],
            pathWithoutLast: [],
            pathLast: "p",
            generics: [],
            typeFilter: null,
        }],
        foundElems: 1,
        userQuery: '"p",',
        returned: [],
        error: null,
    },
    {
        query: '"p" -> a',
        elems: [],
        foundElems: 0,
        userQuery: '"p" -> a',
        returned: [],
        error: "Cannot have more than one element if you use quotes",
    },
    {
        query: '"a" -> "p"',
        elems: [],
        foundElems: 0,
        userQuery: '"a" -> "p"',
        returned: [],
        error: "Cannot have more than one literal search element",
    },
    {
        query: '->"-"',
        elems: [],
        foundElems: 0,
        userQuery: '->"-"',
        returned: [],
        error: 'Unexpected `-` in a string element',
    },
    {
        query: '"a',
        elems: [],
        foundElems: 0,
        userQuery: '"a',
        returned: [],
        error: 'Unclosed `"`',
    },
    {
        query: '""',
        elems: [],
        foundElems: 0,
        userQuery: '""',
        returned: [],
        error: 'Cannot have empty string element',
    },
];
